==> haskell-hspec-contrib-0.5.2-126-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-contrib
version:              0.5.2
visibility:           public
id:                   hspec-contrib-0.5.2-FubQBFUkhiJHB6IMg0YgCz
key:                  hspec-contrib-0.5.2-FubQBFUkhiJHB6IMg0YgCz
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2014 Junji Hashimoto

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             Contributed functionality for Hspec
description:          Contributed functionality for Hspec
category:             Testing
abi:                  30e600630f0b9db43528fd22cc8f0eb7
exposed:              True
exposed-modules:
    Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Mocks.V1
    Test.Hspec.Contrib.Retry

hidden-modules:       Paths_hspec_contrib
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-contrib-0.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-contrib-0.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-contrib-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-contrib
hs-libraries:         HShspec-contrib-0.5.2-FubQBFUkhiJHB6IMg0YgCz
depends:
    HUnit-1.6.2.0-IE0oFrOTEOHIkscEaBk8om base-4.18.2.1
    call-stack-0.4.0-6YsJqSpqGk4Bu2nGz8R6vi
    hspec-core-2.11.4-1HkLPyupJ0H3VqtAEeRZWL

haddock-interfaces:
    /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock

haddock-html:         /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-contrib-0.5.2-127-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-contrib
version:              0.5.2
visibility:           public
id:                   hspec-contrib-0.5.2-E0FZwQosAcE65el2JV5Udw
key:                  hspec-contrib-0.5.2-E0FZwQosAcE65el2JV5Udw
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2014 Junji Hashimoto

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             Contributed functionality for Hspec
description:          Contributed functionality for Hspec
category:             Testing
abi:                  b8ebfc3b788802c259b1f85a5c96a45a
exposed:              True
exposed-modules:
    Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Mocks.V1
    Test.Hspec.Contrib.Retry

hidden-modules:       Paths_hspec_contrib
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-contrib-0.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-contrib-0.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-contrib-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-contrib
hs-libraries:         HShspec-contrib-0.5.2-E0FZwQosAcE65el2JV5Udw
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA base-4.18.2.1
    call-stack-0.4.0-2bP2isqo6m56I7hpBeHX0O
    hspec-core-2.11.4-LH4ljAyFr7833CkU966kHA

haddock-interfaces:
    /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock

haddock-html:         /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
